==> nextcloud-22.2.4.tgz: nextcloud/apps/oauth2/l10n/it.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Il tuo client non è autorizzato a collegarsi. Informa l'amministratore del tuo client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Il tuo URL di redirezione deve essere un URL completo, ad esempio: https://tuodominio.com/percorso",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Consente l'autenticazione compatibile con OAuth2 da altre applicazioni web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "L'applicazione OAuth2 consente agli amministratori di configurare la procedura di autenticazione integrata per consentire anche l'autenticazione compatibile con OAuth2 da altre applicazioni web.",
    "OAuth 2.0 clients" : "Client OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 consente a servizi esterni di richiedere accesso a {instanceName}.",
    "Add client" : "Aggiungi client",
    "Name" : "Nome",
    "Redirection URI" : "URI di redirezione",
    "Add" : "Aggiungi",
    "Client Identifier" : "Identificatore client",
    "Secret" : "Segreto",
    "Show client secret" : "Mostra segreto del client",
    "Delete" : "Elimina"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.9.tgz: nextcloud/apps/oauth2/l10n/it.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Il tuo client non è autorizzato a collegarsi. Informa l'amministratore del tuo client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Il tuo URL di redirezione deve essere un URL completo, ad esempio: https://tuodominio.com/percorso",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Consente l'autenticazione compatibile con OAuth2 da altre applicazioni web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "L'applicazione OAuth2 consente agli amministratori di configurare la procedura di autenticazione integrata per consentire anche l'autenticazione compatibile con OAuth2 da altre applicazioni web.",
    "OAuth 2.0 clients" : "Client OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 consente a servizi esterni di richiedere accesso a {instanceName}.",
    "Add client" : "Aggiungi client",
    "Name" : "Nome",
    "Redirection URI" : "URI di redirezione",
    "Add" : "Aggiungi",
    "Client Identifier" : "Identificatore client",
    "Secret" : "Segreto",
    "Show client secret" : "Mostra segreto del client",
    "Delete" : "Elimina"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
